yakumo.glance.v2.image_member

Package yakumo :: Package glance :: Package v2 :: Module image_member |
[hide private]
[frames] | no frames]

# Module image_member

source code

Resource class and its manager for image members in Image V2 API

Classes | [hide private]
| Resource resource class for image members on Image V2 API
| Manager manager class for image membes on Image V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``user``'``,` `'``member_id``'``,` <yakumo.mapper.Reso`...``
| __package__ = ``'``yakumo.glance.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('user',
        'member_id',
        <yakumo.mapper.Resource object at 0x7f132fe94250>),
       ('image',
        'image_id',
        <yakumo.mapper.Resource object at 0x7f132fe94350>),
       ('schema',
        'schema',
      ...